@@ -13,7 +13,7 @@ class Locations:
         Returns:
             dict: Dictionary with available countries
         """
-        countries_path = os.path.join(current_dir, '..', 'assets', 'countries.json')
+        countries_path = os.path.join(current_dir, "..", "assets", "countries.json")
         with open(countries_path) as countries_file:
             return json.load(countries_file)
 
@@ -27,7 +27,7 @@ class Locations:
         Returns:
             dict: Dictionary with available states if country_code exists
         """
-        states_path = os.path.join(current_dir, '..', 'assets', 'states.json')
+        states_path = os.path.join(current_dir, "..", "assets", "states.json")
         with open(states_path) as states_file:
             states_dict = json.load(states_file)
 
